% CALC_CONTRHO calculates crustal density if we have continental subduction.
%	It creates two matrices:
%	rho: In the case of having continental subduction, the value of rho calculated in 
%		CALC_BETA is replaced in the crust by a new value
%	H: Spacial distribution of crustal radiogenic heat production (Hp)

% Script component of TEMSPOL: a MATLAB thermal model for deep subduction
% zones including major phase transformations.
% A.M. Negredo, J.L. Valera and E. Carminati (2002)


%   The following parameters have been calculated in Init_velo or Velo:
%   x2=x1-L*cot(dip)*(1-cos(dip));
%   x0=x2+L*sin(dip);
%   za=depth-L;
%   c=za+Vs*sin(dip)*time+cot(dip)*(x0+Vs*cos(dip)*time);
%   x4=x3-L*sin(dip);


jcrust=round((depth-hc)/Dz+1); % vertical index of nodes at the base of the crust  
xp3=x4+hc*sin(dip);     % x of the tip of the base of the crustal zone of the slab
x1c=x1+hc*sin(dip);     % x of the point where the base of the crust starts subducting
z3xp3=-cot(dip)*xp3+c;  % z of the tip of the base of the crustal zone of the slab

% Setting indexes of area of the grid where a crustal density and Hp will be assigned 
ix4=round(x4/Dx+1);           % imin
ix1c=round(x1c/Dx+1);         % imax
jxp3=round(z3xp3/Dz+1);       % jmin

% Calculation for z<=depth-hc
for j=jxp3:1:jcrust
    zz=(j-1)*Dz;
    for i=ix4:1:ix1c
 	    xx=(i-1)*Dx;
        % equation of the top of the crustal zone of the slab (z2)
        z2=tan(dip)*xx+za+L-tan(dip)*x1;
        % equation of the front of the crustal zone of the slab (z3)
        z3=-cot(dip)*xx+c;	
        % equation of the base of the crustal zone of the slab (zc4)
        zc4=z2-hc/cos(dip);

        % crustal zone of the dipping slab            
        if zz>=z3
            if zz>=zc4 & zz<=z2 
                rho(i,j)=rhoc;
                H(i,j)=Hp;
	        end
        end
    end
end
% Calculation for z>=depth-hc
rho(1:I,jcrust:J)=rhoc;
H(1:I,jcrust:J)=Hp;

clear z1 z2 z3 zc4 xp3 xp3old z3xp3 ixp3old jxp3 zz xx;
